@@ -2,6 +2,7 @@
 #'
 #' Creates a valid expression to generate a response forest plot.
 #'
+#' @inheritParams tern::g_forest
 #' @inheritParams template_arguments
 #' @param obj_var_name (`character`)\cr additional text to append to the table title.
 #' @param responders (`character`)\cr values of `aval_var` that are considered to be responders.
@@ -9,9 +10,10 @@
 #'  estimator plot symbol. Typically, the symbol size is proportional to the sample size used
 #'  to calculate the estimator. If `NULL`, the same symbol size is used for all subgroups.
 #' @param strata_var (`character`)\cr names of the variables for stratified analysis.
-#' @param ggplot2_args optional, (`ggplot2_args`)\cr object created by [teal.widgets::ggplot2_args()] with settings
-#'   for the module plot. For this module, this argument will only accept `ggplot2_args` object with `labs` list of
-#'   following child elements: `title`, `caption`. No other elements would be taken into account. The argument is
+#' @param ggplot2_args (`ggplot2_args`) optional\cr
+#'   object created by [teal.widgets::ggplot2_args()] with settings for the module plot. For this
+#'   module, this argument will only accept `ggplot2_args` object with `labs` list of following child
+#'   elements: `title`, `caption`. No other elements would be taken into account. The argument is
 #'   merged with option `teal.ggplot2_args` and with default module arguments (hard coded in the module body).
 #'
 #'   For more details, see the vignette: `vignette("custom-ggplot2-arguments", package = "teal.widgets")`.
@@ -33,6 +35,8 @@ template_forest_rsp <- function(dataname = "ANL",
                                 strata_var = NULL,
                                 conf_level = 0.95,
                                 col_symbol_size = NULL,
+                                rel_width_forest = 0.25,
+                                font_size = 15,
                                 ggplot2_args = teal.widgets::ggplot2_args()) {
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -40,6 +44,8 @@ template_forest_rsp <- function(dataname = "ANL",
   checkmate::assert_string(aval_var)
   checkmate::assert_string(obj_var_name)
   checkmate::assert_character(subgroup_var, null.ok = TRUE)
+  checkmate::assert_number(rel_width_forest, lower = 0, upper = 1)
+  checkmate::assert_number(font_size)
 
   y <- list()
   ref_arm_val <- paste(ref_arm, collapse = "/")
@@ -131,7 +137,7 @@ template_forest_rsp <- function(dataname = "ANL",
     substitute(
       expr = df <- extract_rsp_subgroups(
         variables = list(
-          rsp = "is_rsp", arm = arm_var, subgroups = subgroup_var, strat = strata_var
+          rsp = "is_rsp", arm = arm_var, subgroups = subgroup_var, strata = strata_var
         ),
         data = anl,
         conf_level = conf_level
@@ -157,34 +163,55 @@ template_forest_rsp <- function(dataname = "ANL",
   all_ggplot2_args <- teal.widgets::resolve_ggplot2_args(
     user_plot = ggplot2_args,
     module_plot = teal.widgets::ggplot2_args(
-      labs = list(title = paste0("Forest Plot of Best Overall Response for ", obj_var_name), caption = "")
+      labs = list(
+        title = paste("Forest Plot of Best Overall Response for", obj_var_name),
+        caption = ""
+      )
     )
   )
 
-  plot_call <- substitute(
-    expr = g_forest(
-      tbl = result,
-      col_symbol_size = col_s_size
-    ),
-    env = list(col_s_size = col_symbol_size)
+  plot_list <- list()
+
+  plot_list <- add_expr(
+    plot_list,
+    substitute(
+      expr = {
+        f <- g_forest(
+          tbl = result,
+          col_symbol_size = col_s_size,
+          font_size = font_size,
+          as_list = TRUE
+        )
+      },
+      env = list(
+        col_s_size = col_symbol_size,
+        font_size = font_size
+      )
+    )
   )
 
-  plot_call <- substitute(
-    decorate_grob(p, titles = title, footnotes = caption, gp_footnotes = grid::gpar(fontsize = 12)),
-    env = list(title = all_ggplot2_args$labs$title, caption = all_ggplot2_args$labs$caption, p = plot_call)
-  )
-
-  plot_call <- substitute(
-    expr = {
-      p <- plot_call
-      grid::grid.newpage()
-      grid::grid.draw(p)
-    },
-    env = list(plot_call = plot_call)
+  plot_list <- add_expr(
+    plot_list,
+    substitute(
+      expr = {
+        p <- cowplot::plot_grid(
+          f[["table"]] + ggplot2::labs(title = ggplot2_args_title),
+          f[["plot"]] + ggplot2::labs(caption = ggplot2_args_caption),
+          align = "h",
+          axis = "tblr",
+          rel_widths = c(1 - rel_width_forest, rel_width_forest)
+        )
+      },
+      env = list(
+        rel_width_forest = rel_width_forest,
+        ggplot2_args_title = all_ggplot2_args$labs$title,
+        ggplot2_args_caption = all_ggplot2_args$labs$caption
+      )
+    )
   )
 
   # Plot output.
-  y$plot <- plot_call
+  y$plot <- plot_list
 
   y
 }
@@ -193,6 +220,7 @@ template_forest_rsp <- function(dataname = "ANL",
 #'
 #' This module produces a grid-style forest plot for response data with ADaM structure.
 #'
+#' @inheritParams tern::g_forest
 #' @inheritParams module_arguments
 #' @inheritParams template_forest_rsp
 #'
@@ -201,7 +229,6 @@ template_forest_rsp <- function(dataname = "ANL",
 #' @examples
 #' library(nestcolor)
 #' library(dplyr)
-#' library(formatters)
 #'
 #' ADSL <- tmc_ex_adsl
 #' ADRS <- tmc_ex_adrs %>%
@@ -301,12 +328,14 @@ tm_g_forest_rsp <- function(label,
                             fixed_symbol_size = TRUE,
                             conf_level = teal.transform::choices_selected(c(0.95, 0.9, 0.8), 0.95, keep_order = TRUE),
                             default_responses = c("CR", "PR", "Y", "Complete Response (CR)", "Partial Response (PR)"),
-                            plot_height = c(700L, 200L, 2000L),
-                            plot_width = c(1200L, 800L, 3000L),
+                            plot_height = c(500L, 200L, 2000L),
+                            plot_width = c(1500L, 800L, 3000L),
+                            rel_width_forest = c(25L, 0L, 100L),
+                            font_size = c(15L, 1L, 30L),
                             pre_output = NULL,
                             post_output = NULL,
                             ggplot2_args = teal.widgets::ggplot2_args()) {
-  logger::log_info("Initializing tm_g_forest_rsp")
+  message("Initializing tm_g_forest_rsp")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -366,15 +395,15 @@ ui_g_forest_rsp <- function(id, ...) {
   a <- list(...) # module args
   is_single_dataset_value <- teal.transform::is_single_dataset(a$arm_var, a$paramcd, a$subgroup_var, a$strata_var)
 
-  ns <- shiny::NS(id)
+  ns <- NS(id)
 
   teal.widgets::standard_layout(
     output = teal.widgets::plot_with_settings_ui(id = ns("myplot")),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(a[c("arm_var", "paramcd", "aval_var", "subgroup_var", "strata_var")]),
       teal.transform::data_extract_ui(
         id = ns("paramcd"),
@@ -388,7 +417,7 @@ ui_g_forest_rsp <- function(id, ...) {
         data_extract_spec = a$aval_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::selectInput(
+      selectInput(
         ns("responders"),
         "Responders",
         choices = c("CR", "PR"),
@@ -401,7 +430,7 @@ ui_g_forest_rsp <- function(id, ...) {
         data_extract_spec = a$arm_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::uiOutput(
+      uiOutput(
         ns("arms_buckets"),
         title = paste(
           "Multiple reference groups are automatically combined into a single group when more than one",
@@ -431,11 +460,23 @@ ui_g_forest_rsp <- function(id, ...) {
             multiple = FALSE,
             fixed = a$conf_level$fixed
           ),
-          shiny::checkboxInput(ns("fixed_symbol_size"), "Fixed symbol size", value = TRUE)
+          checkboxInput(ns("fixed_symbol_size"), "Fixed symbol size", value = TRUE),
+          teal.widgets::optionalSliderInputValMinMax(
+            ns("rel_width_forest"),
+            "Relative Width of Forest Plot (%)",
+            a$rel_width_forest,
+            ticks = FALSE, step = 1
+          ),
+          teal.widgets::optionalSliderInputValMinMax(
+            ns("font_size"),
+            "Table Font Size",
+            a$font_size,
+            ticks = FALSE, step = 1
+          )
         )
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), "Show R code")
     ),
@@ -465,9 +506,9 @@ srv_g_forest_rsp <- function(id,
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
-  checkmate::assert_class(shiny::isolate(data()), "teal_data")
+  checkmate::assert_class(isolate(data()), "teal_data")
 
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     # Setup arm variable selection, default reference arms, and default
     # comparison arms for encoding panel
     iv_arm_ref <- arm_ref_comp_observer(
@@ -496,7 +537,7 @@ srv_g_forest_rsp <- function(id,
       filter_validation_rule = list(paramcd = shinyvalidate::sv_required(message = "Please select Endpoint filter."))
     )
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
       iv$add_rule("conf_level", shinyvalidate::sv_required("Please choose a confidence level between 0 and 1"))
       iv$add_rule(
@@ -520,19 +561,19 @@ srv_g_forest_rsp <- function(id,
       anl_name = "ANL_ADSL"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(code = as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(code = as.expression(adsl_inputs()$expr))
     })
 
-    shiny::observeEvent(
+    observeEvent(
       eventExpr = c(
         input[[extract_input("aval_var", "ADRS")]],
         input[[extract_input("paramcd", paramcd$filter[[1]]$dataname, filter = TRUE)]]
       ),
       handlerExpr = {
-        shiny::req(anl_q())
+        req(anl_q())
         anl <- anl_q()[["ANL"]]
         aval_var <- anl_inputs()$columns_source$aval_var
         paramcd_level <- unlist(anl_inputs()$filter_info$paramcd[[1]]$selected)
@@ -565,7 +606,7 @@ srv_g_forest_rsp <- function(id,
             unique(anl[[aval_var]])
           }
         }
-        shiny::updateSelectInput(
+        updateSelectInput(
           session, "responders",
           choices = responder_choices,
           selected = intersect(responder_choices, common_rsp)
@@ -574,9 +615,9 @@ srv_g_forest_rsp <- function(id,
     )
 
     # Prepare the analysis environment (filter data, check data, populate envir).
-    validate_checks <- shiny::reactive({
+    validate_checks <- reactive({
       teal::validate_inputs(iv_r())
-      shiny::req(anl_q())
+      req(anl_q())
       adsl_filtered <- anl_q()[[parentname]]
       anl_filtered <- anl_q()[[dataname]]
       anl <- anl_q()[["ANL"]]
@@ -606,16 +647,16 @@ srv_g_forest_rsp <- function(id,
       teal::validate_one_row_per_id(anl_q()[["ANL"]], key = c("USUBJID", "STUDYID", input_paramcd))
 
       if (length(input_subgroup_var) > 0) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(vapply(adsl_filtered[, input_subgroup_var], is.factor, logical(1))),
             "Not all subgroup variables are factors."
           )
         )
       }
       if (length(input_strata_var) > 0) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(vapply(adsl_filtered[, input_strata_var], is.factor, logical(1))),
             "Not all stratification variables are factors."
           )
@@ -623,8 +664,8 @@ srv_g_forest_rsp <- function(id,
       }
 
       if (!identical(default_responses, c("CR", "PR", "Y", "Complete Response (CR)", "Partial Response (PR)"))) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(unlist(lapply(default_responses, function(x) {
               if (is.list(x) & "levels" %in% names(x)) {
                 lvls <- x$levels
@@ -644,8 +685,8 @@ srv_g_forest_rsp <- function(id,
       }
 
       if (is.list(default_responses)) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(
               grepl("\\.rsp|\\.levels", names(unlist(default_responses))) |
                 names(unlist(default_responses)) %in% names(default_responses)
@@ -660,7 +701,7 @@ srv_g_forest_rsp <- function(id,
     })
 
     # The R-code corresponding to the analysis.
-    all_q <- shiny::reactive({
+    all_q <- reactive({
       validate_checks()
       anl_m <- anl_inputs()
 
@@ -682,13 +723,15 @@ srv_g_forest_rsp <- function(id,
         strata_var = if (length(strata_var) != 0) strata_var else NULL,
         conf_level = as.numeric(input$conf_level),
         col_symbol_size = `if`(input$fixed_symbol_size, NULL, 1),
+        rel_width_forest = input$rel_width_forest / 100,
+        font_size = input$font_size,
         ggplot2_args = ggplot2_args
       )
 
       teal.code::eval_code(anl_q(), as.expression(my_calls))
     })
 
-    plot_r <- shiny::reactive(all_q()[["p"]])
+    plot_r <- reactive(all_q()[["p"]])
 
     pws <- teal.widgets::plot_with_settings_srv(
       id = "myplot",
@@ -699,14 +742,14 @@ srv_g_forest_rsp <- function(id,
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(all_q())),
+      verbatim_content = reactive(teal.code::get_warnings(all_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(all_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
     )
 
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive(teal.code::get_code(all_q())),
+      verbatim_content = reactive(teal.code::get_code(all_q())),
       title = label
     )
 
