@@ -23,11 +23,15 @@ template_forest_tte <- function(dataname = "ANL",
                                 conf_level = 0.95,
                                 col_symbol_size = NULL,
                                 time_unit_var = "AVALU",
+                                rel_width_forest = 0.25,
+                                font_size = 15,
                                 ggplot2_args = teal.widgets::ggplot2_args()) {
   checkmate::assert_string(dataname)
   checkmate::assert_string(arm_var)
   checkmate::assert_string(obj_var_name)
   checkmate::assert_character(subgroup_var, null.ok = TRUE)
+  checkmate::assert_number(rel_width_forest, lower = 0, upper = 1)
+  checkmate::assert_number(font_size)
 
   y <- list()
   ref_arm_val <- paste(ref_arm, collapse = "/")
@@ -120,7 +124,7 @@ template_forest_tte <- function(dataname = "ANL",
           is_event = "is_event",
           arm = arm_var,
           subgroups = subgroup_var,
-          strat = strata_var
+          strata = strata_var
         ),
         control = control_coxph(conf_level = conf_level),
         data = anl
@@ -154,45 +158,59 @@ template_forest_tte <- function(dataname = "ANL",
     user_plot = ggplot2_args,
     module_plot = teal.widgets::ggplot2_args(
       labs = list(
-        title = paste("Forest Plot of Survival Duration for", obj_var_name),
-        subtitle = ifelse(is.null(strata_var), "", paste("Stratified by", paste(strata_var, collapse = " and "))),
+        title = paste(
+          paste("Forest Plot of Survival Duration for", obj_var_name),
+          ifelse(is.null(strata_var), "", paste("Stratified by", paste(strata_var, collapse = " and "))),
+          sep = "\n"
+        ),
         caption = ""
       )
     )
   )
 
-  plot_call <- substitute(
-    expr = g_forest(
-      tbl = result,
-      col_symbol_size = col_s_size
-    ),
-    env = list(col_s_size = col_symbol_size)
-  )
+  plot_list <- list()
 
-  plot_call <- substitute(
-    decorate_grob(p, titles = title, footnotes = caption, gp_footnotes = grid::gpar(fontsize = 12)),
-    env = list(
-      title = `if`(
-        all_ggplot2_args$labs$subtitle == "",
-        all_ggplot2_args$labs$title,
-        c(all_ggplot2_args$labs$title, all_ggplot2_args$labs$subtitle)
-      ),
-      caption = all_ggplot2_args$labs$caption,
-      p = plot_call
+  plot_list <- add_expr(
+    plot_list,
+    substitute(
+      expr = {
+        f <- g_forest(
+          tbl = result,
+          col_symbol_size = col_s_size,
+          font_size = font_size,
+          as_list = TRUE
+        )
+      },
+      env = list(
+        col_s_size = col_symbol_size,
+        font_size = font_size
+      )
     )
   )
 
-  plot_call <- substitute(
-    env = list(plot_call = plot_call),
-    expr = {
-      p <- plot_call
-      grid::grid.newpage()
-      grid::grid.draw(p)
-    }
+  plot_list <- add_expr(
+    plot_list,
+    substitute(
+      expr = {
+        p <- cowplot::plot_grid(
+          f[["table"]] + ggplot2::labs(title = ggplot2_args_title, subtitle = ggplot2_args_subtitle),
+          f[["plot"]] + ggplot2::labs(caption = ggplot2_args_caption),
+          align = "h",
+          axis = "tblr",
+          rel_widths = c(1 - rel_width_forest, rel_width_forest)
+        )
+      },
+      env = list(
+        rel_width_forest = rel_width_forest,
+        ggplot2_args_title = all_ggplot2_args$labs$title,
+        ggplot2_args_subtitle = all_ggplot2_args$labs$subtitle,
+        ggplot2_args_caption = all_ggplot2_args$labs$caption
+      )
+    )
   )
 
   # Plot output.
-  y$plot <- plot_call
+  y$plot <- plot_list
 
   y
 }
@@ -201,6 +219,7 @@ template_forest_tte <- function(dataname = "ANL",
 #'
 #' This module produces a grid-style forest plot for time-to-event data with ADaM structure.
 #'
+#' @inheritParams tern::g_forest
 #' @inheritParams module_arguments
 #' @inheritParams template_forest_tte
 #'
@@ -208,7 +227,6 @@ template_forest_tte <- function(dataname = "ANL",
 #'
 #' @examples
 #' library(nestcolor)
-#' library(formatters)
 #'
 #' ADSL <- tmc_ex_adsl
 #' ADTTE <- tmc_ex_adtte
@@ -255,8 +273,7 @@ template_forest_tte <- function(dataname = "ANL",
 #'       strata_var = choices_selected(
 #'         variable_choices(ADSL, c("STRATA1", "STRATA2")),
 #'         "STRATA2"
-#'       ),
-#'       plot_height = c(600, 200, 2000)
+#'       )
 #'     )
 #'   )
 #' )
@@ -291,12 +308,14 @@ tm_g_forest_tte <- function(label,
                               fixed = TRUE
                             ),
                             fixed_symbol_size = TRUE,
-                            plot_height = c(700L, 200L, 2000L),
-                            plot_width = c(1200L, 800L, 3000L),
+                            plot_height = c(500L, 200L, 2000L),
+                            plot_width = c(1500L, 800L, 3000L),
+                            rel_width_forest = c(25L, 0L, 100L),
+                            font_size = c(15L, 1L, 30L),
                             pre_output = NULL,
                             post_output = NULL,
                             ggplot2_args = teal.widgets::ggplot2_args()) {
-  logger::log_info("Initializing tm_g_forest_tte")
+  message("Initializing tm_g_forest_tte")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -365,15 +384,15 @@ ui_g_forest_tte <- function(id, ...) {
     a$time_unit_var
   )
 
-  ns <- shiny::NS(id)
+  ns <- NS(id)
 
   teal.widgets::standard_layout(
     output = teal.widgets::plot_with_settings_ui(id = ns("myplot")),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(a[c("arm_var", "paramcd", "subgroup_var", "strata_var", "aval_var", "cnsr_var")]),
       teal.transform::data_extract_ui(
         id = ns("paramcd"),
@@ -399,7 +418,7 @@ ui_g_forest_tte <- function(id, ...) {
         data_extract_spec = a$arm_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::uiOutput(
+      uiOutput(
         ns("arms_buckets"),
         title = paste(
           "Multiple reference groups are automatically combined into a single group when more than one",
@@ -429,17 +448,29 @@ ui_g_forest_tte <- function(id, ...) {
             multiple = FALSE,
             fixed = a$conf_level$fixed
           ),
-          shiny::checkboxInput(ns("fixed_symbol_size"), "Fixed symbol size", value = TRUE),
+          checkboxInput(ns("fixed_symbol_size"), "Fixed symbol size", value = TRUE),
           teal.transform::data_extract_ui(
             id = ns("time_unit_var"),
             label = "Time Unit Variable",
             data_extract_spec = a$time_unit_var,
             is_single_dataset = is_single_dataset_value
+          ),
+          teal.widgets::optionalSliderInputValMinMax(
+            ns("rel_width_forest"),
+            "Relative Width of Forest Plot (%)",
+            a$rel_width_forest,
+            ticks = FALSE, step = 1
+          ),
+          teal.widgets::optionalSliderInputValMinMax(
+            ns("font_size"),
+            "Table Font Size",
+            a$font_size,
+            ticks = FALSE, step = 1
           )
         )
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
@@ -469,9 +500,9 @@ srv_g_forest_tte <- function(id,
   with_reporter <- !missing(reporter) && inherits(reporter, "Reporter")
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
-  checkmate::assert_class(shiny::isolate(data()), "teal_data")
+  checkmate::assert_class(isolate(data()), "teal_data")
 
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     # Setup arm variable selection, default reference arms, and default
     # comparison arms for encoding panel
     iv_arm_ref <- arm_ref_comp_observer(
@@ -503,7 +534,7 @@ srv_g_forest_tte <- function(id,
       filter_validation_rule = list(paramcd = shinyvalidate::sv_required(message = "Please select Endpoint filter."))
     )
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
       iv$add_rule("conf_level", shinyvalidate::sv_required("Please choose a confidence level"))
       iv$add_rule(
@@ -526,13 +557,13 @@ srv_g_forest_tte <- function(id,
       anl_name = "ANL_ADSL"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
     })
 
-    validate_checks <- shiny::reactive({
+    validate_checks <- reactive({
       teal::validate_inputs(iv_r())
       adsl_filtered <- anl_q()[[parentname]]
       anl_filtered <- anl_q()[[dataname]]
@@ -565,8 +596,8 @@ srv_g_forest_tte <- function(id,
       )
 
       if (length(input_subgroup_var) > 0) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(vapply(adsl_filtered[, input_subgroup_var], is.factor, logical(1))),
             "Not all subgroup variables are factors."
           )
@@ -574,8 +605,8 @@ srv_g_forest_tte <- function(id,
       }
 
       if (length(input_strata_var) > 0) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(vapply(adsl_filtered[, input_strata_var], is.factor, logical(1))),
             "Not all stratification variables are factors."
           )
@@ -584,7 +615,7 @@ srv_g_forest_tte <- function(id,
 
       do.call(what = "validate_standard_inputs", validate_args)
 
-      shiny::validate(shiny::need(
+      validate(need(
         length(anl[[input_paramcd]]) > 0,
         "Value of the endpoint variable should not be empty."
       ))
@@ -593,7 +624,7 @@ srv_g_forest_tte <- function(id,
     })
 
     # The R-code corresponding to the analysis.
-    all_q <- shiny::reactive({
+    all_q <- reactive({
       validate_checks()
 
       anl_m <- anl_inputs()
@@ -617,13 +648,15 @@ srv_g_forest_tte <- function(id,
         conf_level = as.numeric(input$conf_level),
         col_symbol_size = if (!input$fixed_symbol_size) 1,
         time_unit_var = as.vector(anl_m$columns_source$time_unit_var),
+        rel_width_forest = input$rel_width_forest / 100,
+        font_size = input$font_size,
         ggplot2_args = ggplot2_args
       )
       teal.code::eval_code(anl_q(), as.expression(my_calls))
     })
 
     # Outputs to render.
-    plot_r <- shiny::reactive(all_q()[["p"]])
+    plot_r <- reactive(all_q()[["p"]])
 
     pws <- teal.widgets::plot_with_settings_srv(
       id = "myplot",
@@ -634,14 +667,14 @@ srv_g_forest_tte <- function(id,
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(all_q())),
+      verbatim_content = reactive(teal.code::get_warnings(all_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(all_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
     )
 
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive(teal.code::get_code(all_q())),
+      verbatim_content = reactive(teal.code::get_code(all_q())),
       title = "R Code for the Current Time-to-Event Forest Plot"
     )
 
