@@ -331,6 +331,15 @@ template_binary_outcome <- function(dataname,
 #' @inheritParams module_arguments
 #' @inheritParams template_binary_outcome
 #' @param rsp_table (`logical`)\cr whether the initial set-up of the module should match `RSPT01`. Defaults to `FALSE`.
+#' @param control (named `list`)\cr named list containing 3 named lists as follows:
+#'   * `global`: a list of settings for overall analysis with 2 named elements `method` and `conf_level`.
+#'   * `unstrat`: a list of settings for unstratified analysis with 3 named elements `method_ci` and `method_test`, and
+#'     `odds`. See [tern::estimate_proportion_diff()], [tern::test_proportion_diff()], and
+#'     [tern::estimate_odds_ratio()], respectively, for options and details on how these settings are implemented in the
+#'     analysis.
+#'   * `strat`: a list of settings for stratified analysis with elements `method_ci` and `method_test`. See
+#'     [tern::estimate_proportion_diff()] and [tern::test_proportion_diff()], respectively, for options and details on
+#'     how these settings are implemented in the analysis.
 #'
 #' @details
 #' * The display order of response categories inherits the factor level order of the source data. Use
@@ -344,7 +353,6 @@ template_binary_outcome <- function(dataname,
 #'
 #' @examples
 #' library(dplyr)
-#' library(formatters)
 #'
 #' ADSL <- tmc_ex_adsl
 #' ADRS <- tmc_ex_adrs %>%
@@ -387,7 +395,7 @@ template_binary_outcome <- function(dataname,
 #'       arm_ref_comp = arm_ref_comp,
 #'       strata_var = choices_selected(
 #'         choices = variable_choices(ADRS, c("SEX", "BMRKR2", "RACE")),
-#'         select = "RACE"
+#'         selected = "RACE"
 #'       ),
 #'       default_responses = list(
 #'         BESRSPI = list(
@@ -439,13 +447,25 @@ tm_t_binary_outcome <- function(label,
                                 default_responses =
                                   c("CR", "PR", "Y", "Complete Response (CR)", "Partial Response (PR)", "M"),
                                 rsp_table = FALSE,
+                                control = list(
+                                  global = list(
+                                    method = ifelse(rsp_table, "clopper-pearson", "waldcc"),
+                                    conf_level = 0.95
+                                  ),
+                                  unstrat = list(
+                                    method_ci = ifelse(rsp_table, "wald", "waldcc"),
+                                    method_test = "schouten",
+                                    odds = TRUE
+                                  ),
+                                  strat = list(method_ci = "cmh", method_test = "cmh")
+                                ),
                                 add_total = FALSE,
                                 total_label = default_total_label(),
                                 na_level = default_na_str(),
                                 pre_output = NULL,
                                 post_output = NULL,
                                 basic_table_args = teal.widgets::basic_table_args()) {
-  logger::log_info("Initializing tm_t_binary_outcome")
+  message("Initializing tm_t_binary_outcome")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -467,6 +487,24 @@ tm_t_binary_outcome <- function(label,
   checkmate::assert_class(post_output, classes = "shiny.tag", null.ok = TRUE)
   checkmate::assert_class(basic_table_args, "basic_table_args")
 
+  # control checks
+  checkmate::assert_names(names(control), permutation.of = c("global", "unstrat", "strat"))
+  checkmate::assert_names(names(control$global), permutation.of = c("method", "conf_level"))
+  checkmate::assert_names(names(control$unstrat), permutation.of = c("method_ci", "method_test", "odds"))
+  checkmate::assert_names(names(control$strat), permutation.of = c("method_ci", "method_test"))
+  checkmate::assert_subset(
+    control$global$method,
+    c("wald", "waldcc", "clopper-pearson", "wilson", "wilsonc", "jeffreys", "agresti-coull")
+  )
+  checkmate::assert_number(control$global$conf_level, lower = 0, upper = 1)
+  checkmate::assert_subset(control$unstrat$method_ci, c("wald", "waldcc", "ha", "newcombe", "newcombecc"))
+  checkmate::assert_subset(control$unstrat$method_test, c("chisq", "fisher", "schouten"))
+  checkmate::assert_logical(control$unstrat$odds)
+  checkmate::assert_subset(
+    control$strat$method_ci, c("wald", "waldcc", "cmh", "ha", "strat_newcombe", "strat_newcombecc")
+  )
+  checkmate::assert_subset(control$strat$method_test, c("cmh"))
+
   args <- as.list(environment())
 
   data_extract_list <- list(
@@ -490,6 +528,7 @@ tm_t_binary_outcome <- function(label,
         label = label,
         total_label = total_label,
         default_responses = default_responses,
+        control = control,
         rsp_table = rsp_table,
         na_level = na_level,
         basic_table_args = basic_table_args
@@ -509,14 +548,14 @@ ui_t_binary_outcome <- function(id, ...) {
     a$strata_var
   )
 
-  ns <- shiny::NS(id)
+  ns <- NS(id)
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(a[c("paramcd", "arm_var", "aval_var", "strata_var")]),
       teal.transform::data_extract_ui(
         id = ns("paramcd"),
@@ -524,7 +563,7 @@ ui_t_binary_outcome <- function(id, ...) {
         data_extract_spec = a$paramcd,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::selectInput(
+      selectInput(
         ns("responders"),
         "Responders",
         choices = NULL,
@@ -537,26 +576,26 @@ ui_t_binary_outcome <- function(id, ...) {
         data_extract_spec = a$arm_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::div(
+      tags$div(
         class = "arm-comp-box",
-        shiny::tags$label("Compare Treatments"),
+        tags$label("Compare Treatments"),
         shinyWidgets::switchInput(
           inputId = ns("compare_arms"),
           value = !is.null(a$arm_ref_comp),
           size = "mini"
         ),
-        shiny::conditionalPanel(
+        conditionalPanel(
           condition = paste0("input['", ns("compare_arms"), "']"),
-          shiny::div(
-            shiny::uiOutput(
+          tags$div(
+            uiOutput(
               ns("arms_buckets"),
               title = paste(
                 "Multiple reference groups are automatically combined into a single group when more than one",
                 "value is selected."
               )
             ),
-            shiny::helpText("Multiple reference groups are automatically combined into a single group."),
-            shiny::checkboxInput(
+            helpText("Multiple reference groups are automatically combined into a single group."),
+            checkboxInput(
               ns("combine_comp_arms"),
               "Combine all comparison groups?",
               value = FALSE
@@ -564,7 +603,7 @@ ui_t_binary_outcome <- function(id, ...) {
           )
         )
       ),
-      shiny::conditionalPanel(
+      conditionalPanel(
         condition = paste0("input['", ns("compare_arms"), "']"),
         teal.widgets::panel_group(
           teal.widgets::panel_item(
@@ -579,7 +618,7 @@ ui_t_binary_outcome <- function(id, ...) {
                 "Newcombe, without correction" = "newcombe",
                 "Newcombe, with correction" = "newcombecc"
               ),
-              selected = ifelse(a$rsp_table, "wald", "waldcc"),
+              selected = a$control$unstrat$method_ci,
               multiple = FALSE,
               fixed = FALSE
             ),
@@ -591,13 +630,13 @@ ui_t_binary_outcome <- function(id, ...) {
                 "Fisher's Exact Test" = "fisher",
                 "Chi-Squared Test with Schouten correction" = "schouten"
               ),
-              selected = "chisq",
+              selected = a$control$unstrat$method_test,
               multiple = FALSE,
               fixed = FALSE
             ),
-            shiny::tags$label("Odds Ratio Estimation"),
+            tags$label("Odds Ratio Estimation"),
             shinyWidgets::switchInput(
-              inputId = ns("u_odds_ratio"), value = TRUE, size = "mini"
+              inputId = ns("u_odds_ratio"), value = a$control$unstrat$odds, size = "mini"
             )
           )
         ),
@@ -621,23 +660,23 @@ ui_t_binary_outcome <- function(id, ...) {
                 "Stratified Newcombe, without correction" = "strat_newcombe",
                 "Stratified Newcombe, with correction" = "strat_newcombecc"
               ),
-              selected = "cmh",
+              selected = a$control$strat$method_ci,
               multiple = FALSE
             ),
             teal.widgets::optionalSelectInput(
               ns("s_diff_test"),
               label = "Method for Difference of Proportions Test",
               choices = c("CMH Test" = "cmh"),
-              selected = "cmh",
+              selected = a$control$strat$method_test,
               multiple = FALSE,
               fixed = TRUE
             )
           )
         )
       ),
-      shiny::conditionalPanel(
+      conditionalPanel(
         condition = paste0("!input['", ns("compare_arms"), "']"),
-        shiny::checkboxInput(ns("add_total"), "Add All Patients column", value = a$add_total)
+        checkboxInput(ns("add_total"), "Add All Patients column", value = a$add_total)
       ),
       teal.widgets::panel_item(
         "Additional table settings",
@@ -653,7 +692,7 @@ ui_t_binary_outcome <- function(id, ...) {
             "Jeffreys" = "jeffreys",
             "Agresti-Coull" = "agresti-coull"
           ),
-          selected = ifelse(a$rsp_table, "clopper-pearson", "waldcc"),
+          selected = a$control$global$method,
           multiple = FALSE,
           fixed = FALSE
         ),
@@ -665,7 +704,7 @@ ui_t_binary_outcome <- function(id, ...) {
           multiple = FALSE,
           fixed = a$conf_level$fixed
         ),
-        shiny::tags$label("Show All Response Categories"),
+        tags$label("Show All Response Categories"),
         shinyWidgets::switchInput(
           inputId = ns("show_rsp_cat"),
           value = ifelse(a$rsp_table, TRUE, FALSE),
@@ -679,7 +718,7 @@ ui_t_binary_outcome <- function(id, ...) {
         is_single_dataset = is_single_dataset_value
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
@@ -701,6 +740,7 @@ srv_t_binary_outcome <- function(id,
                                  arm_ref_comp,
                                  strata_var,
                                  add_total,
+                                 control,
                                  total_label,
                                  label,
                                  default_responses,
@@ -712,7 +752,7 @@ srv_t_binary_outcome <- function(id,
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     # Setup arm variable selection, default reference arms, and default
     # comparison arms for encoding panel
     iv_arm_ref <- arm_ref_comp_observer(
@@ -723,7 +763,7 @@ srv_t_binary_outcome <- function(id,
       data = data()[[parentname]],
       arm_ref_comp = arm_ref_comp,
       module = "tm_t_binary_outcome",
-      on_off = shiny::reactive(input$compare_arms)
+      on_off = reactive(input$compare_arms)
     )
 
     selector_list <- teal.transform::data_extract_multiple_srv(
@@ -736,7 +776,7 @@ srv_t_binary_outcome <- function(id,
       filter_validation_rule = list(paramcd = shinyvalidate::sv_required(message = "Please select a filter."))
     )
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
 
       if (isTRUE(input$compare_arms)) {
@@ -764,13 +804,13 @@ srv_t_binary_outcome <- function(id,
       anl_name = "ANL_ADSL"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
     })
 
-    shiny::observeEvent(
+    observeEvent(
       c(
         input[[extract_input("aval_var", "ADRS")]],
         input[[extract_input("paramcd", paramcd$filter[[1]]$dataname, filter = TRUE)]]
@@ -802,7 +842,7 @@ srv_t_binary_outcome <- function(id,
             unique(anl[[aval_var]])
           }
         }
-        shiny::updateSelectInput(
+        updateSelectInput(
           session, "responders",
           choices = responder_choices,
           selected = intersect(responder_choices, common_rsp)
@@ -810,7 +850,7 @@ srv_t_binary_outcome <- function(id,
       }
     )
 
-    validate_check <- shiny::reactive({
+    validate_check <- reactive({
       teal::validate_inputs(iv_r())
       adsl_filtered <- anl_q()[[parentname]]
       anl_filtered <- anl_q()[[dataname]]
@@ -844,9 +884,9 @@ srv_t_binary_outcome <- function(id,
 
       teal::validate_one_row_per_id(anl, key = c("USUBJID", "STUDYID", input_paramcd))
 
-      shiny::validate(
+      validate(
         if (length(input_strata_var) >= 1L) {
-          shiny::need(
+          need(
             sum(
               vapply(
                 anl[input_strata_var],
@@ -861,9 +901,9 @@ srv_t_binary_outcome <- function(id,
         }
       )
 
-      shiny::validate(
+      validate(
         if (length(input_strata_var) >= 1L) {
-          shiny::need(
+          need(
             sum(
               vapply(
                 anl[input_strata_var],
@@ -881,8 +921,8 @@ srv_t_binary_outcome <- function(id,
       )
 
       if (is.list(default_responses)) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             all(
               grepl("\\.rsp|\\.levels", names(unlist(default_responses))) |
                 gsub("[0-9]*", "", names(unlist(default_responses))) %in% names(default_responses)
@@ -895,7 +935,7 @@ srv_t_binary_outcome <- function(id,
       NULL
     })
 
-    table_q <- shiny::reactive({
+    table_q <- reactive({
       validate_check()
 
       qenv <- anl_q()
@@ -903,7 +943,7 @@ srv_t_binary_outcome <- function(id,
       anl <- qenv[["ANL"]]
 
       input_aval_var <- as.vector(anl_m$columns_source$aval_var)
-      shiny::req(input$responders %in% anl[[input_aval_var]])
+      req(input$responders %in% anl[[input_aval_var]])
 
       input_strata_var <- as.vector(anl_m$columns_source$strata_var)
       input_paramcd <- unlist(anl_m$filter_info$paramcd)["selected"]
@@ -955,7 +995,7 @@ srv_t_binary_outcome <- function(id,
     })
 
     # Outputs to render.
-    table_r <- shiny::reactive(table_q()[["result"]])
+    table_r <- reactive(table_q()[["result"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
@@ -964,15 +1004,15 @@ srv_t_binary_outcome <- function(id,
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(table_q())),
+      verbatim_content = reactive(teal.code::get_warnings(table_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(table_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(table_q())))
     )
 
     # Render R code.
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive({
+      verbatim_content = reactive({
         teal.code::get_code(table_q())
       }),
       title = label
