@@ -510,7 +510,7 @@ tm_t_coxreg <- function(label,
                         pre_output = NULL,
                         post_output = NULL,
                         basic_table_args = teal.widgets::basic_table_args()) {
-  logger::log_info("Initializing tm_t_coxreg")
+  message("Initializing tm_t_coxreg")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -569,24 +569,24 @@ ui_t_coxreg <- function(id, ...) {
     a$cov_var
   )
 
-  ns <- shiny::NS(id)
+  ns <- NS(id)
 
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::radioButtons(
+      radioButtons(
         ns("type"),
-        label = shiny::tags$label("Type of Regression:", class = "text-primary"),
+        label = tags$label("Type of Regression:", class = "text-primary"),
         choices = c(
           "Separate models for comparison groups with one covariate at a time" = "Univariate",
           "One model with all comparison groups and covariates" = "Multivariate"
         ),
         selected = dplyr::if_else(a$multivariate, "Multivariate", "Univariate")
       ),
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(
         a[c("arm_var", "paramcd", "subgroup_var", "strata_var", "aval_var", "cnsr_var", "cov_var")]
       ),
@@ -614,10 +614,10 @@ ui_t_coxreg <- function(id, ...) {
         data_extract_spec = a$arm_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::uiOutput(ns("arms_buckets")),
-      shiny::conditionalPanel(
+      uiOutput(ns("arms_buckets")),
+      conditionalPanel(
         condition = paste0("input['", ns("type"), "'] == 'Multivariate'"),
-        shiny::checkboxInput(
+        checkboxInput(
           ns("combine_comp_arms"),
           "Combine all comparison groups?"
         )
@@ -628,14 +628,14 @@ ui_t_coxreg <- function(id, ...) {
         data_extract_spec = a$cov_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::conditionalPanel(
+      conditionalPanel(
         condition = paste0("input['", ns("type"), "'] == 'Univariate'"),
-        shiny::checkboxInput(
+        checkboxInput(
           ns("interactions"),
           "Interaction terms"
         )
       ),
-      shiny::uiOutput(ns("interaction_input")),
+      uiOutput(ns("interaction_input")),
       teal.transform::data_extract_ui(
         id = ns("strata_var"),
         label = "Stratify by",
@@ -645,24 +645,24 @@ ui_t_coxreg <- function(id, ...) {
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional table settings",
-          shiny::conditionalPanel(
+          conditionalPanel(
             condition = paste0("input['", ns("strata_var"), "'] != ''"),
-            shiny::radioButtons(
+            radioButtons(
               ns("pval_method"),
-              label = shiny::p(
+              label = tags$p(
                 "p-value method for",
-                shiny::span(class = "text-primary", "Coxph"),
+                tags$span(class = "text-primary", "Coxph"),
                 "(Hazard Ratio)"
               ),
               choices = c("wald", "likelihood"),
               selected = "wald"
             )
           ),
-          shiny::radioButtons(
+          radioButtons(
             ns("ties"),
-            label = shiny::p(
+            label = tags$p(
               "Ties for ",
-              shiny::span(class = "text-primary", "Coxph"),
+              tags$span(class = "text-primary", "Coxph"),
               " (Hazard Ratio)",
               sep = ""
             ),
@@ -671,9 +671,9 @@ ui_t_coxreg <- function(id, ...) {
           ),
           teal.widgets::optionalSelectInput(
             inputId = ns("conf_level"),
-            label = shiny::p(
+            label = tags$p(
               "Confidence level for ",
-              shiny::span(class = "text-primary", "Coxph"),
+              tags$span(class = "text-primary", "Coxph"),
               " (Hazard Ratio)",
               sep = ""
             ),
@@ -685,7 +685,7 @@ ui_t_coxreg <- function(id, ...) {
         )
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
@@ -716,19 +716,19 @@ srv_t_coxreg <- function(id,
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     # Observer to update reference and comparison arm input options.
     iv_arm_ref <- arm_ref_comp_observer(
       session,
       input,
       output,
       id_arm_var = extract_input("arm_var", parentname),
-      data = shiny::reactive(data()[[parentname]]),
+      data = reactive(data()[[parentname]]),
       arm_ref_comp = arm_ref_comp,
       module = "tm_t_coxreg"
     )
 
-    use_interactions <- shiny::reactive({
+    use_interactions <- reactive({
       input$type == "Univariate" && isTRUE(input$interactions)
     })
 
@@ -789,7 +789,7 @@ srv_t_coxreg <- function(id,
     }
 
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
       iv$add_validator(iv_arm_ref)
       iv$add_rule("conf_level", shinyvalidate::sv_required("Please choose a confidence level"))
@@ -820,7 +820,7 @@ srv_t_coxreg <- function(id,
       merge_function = "dplyr::inner_join"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr))
     })
@@ -835,14 +835,14 @@ srv_t_coxreg <- function(id,
       # For every numeric covariate, the numeric level for the Hazard Ration
       # estimation is proposed only if the covariate is included in the model:
       # for this purpose, a function and a UI-rendered output.
-      shiny::textInput(
+      textInput(
         session$ns(paste0("interact_", x)),
         label = paste("Hazard Ratios for", x, "at (comma delimited):"),
         value = as.character(stats::median(dataset[[x]]))
       )
     }
 
-    interaction_var_r <- shiny::reactive({
+    interaction_var_r <- reactive({
       # exclude cases when increments are not necessary and
       # finally accessing the UI-rendering function defined above.
       if (use_interactions()) {
@@ -855,14 +855,14 @@ srv_t_coxreg <- function(id,
       }
     })
 
-    output$interaction_input <- shiny::renderUI({
+    output$interaction_input <- renderUI({
       if (length(interaction_var_r()) > 0) {
         lapply(interaction_var_r(), open_textinput, dataset = merged$anl_q()[[dataname]])
       }
     })
 
     ## Prepare the call evaluation environment ----
-    validate_checks <- shiny::reactive({
+    validate_checks <- reactive({
       teal::validate_inputs(iv_r())
 
       adsl_filtered <- merged$anl_q()[[parentname]]
@@ -903,14 +903,14 @@ srv_t_coxreg <- function(id,
       } else {
         c(sum(arm_n[unlist(input$buckets$Ref)]), arm_n[unlist(input$buckets$Comp)])
       }
-      shiny::validate(shiny::need(
+      validate(shiny::need(
         all(anl_arm_n >= 2),
         "Each treatment group should have at least 2 records."
       ))
 
       # validate covariate has at least two levels
-      shiny::validate(
-        shiny::need(
+      validate(
+        need(
           all(vapply(anl_filtered[input_cov_var], FUN = function(x) {
             length(unique(x)) > 1
           }, logical(1))),
@@ -921,7 +921,7 @@ srv_t_coxreg <- function(id,
       NULL
     })
 
-    at <- shiny::reactive({
+    at <- reactive({
       input_cov_var <- as.vector(merged$anl_input_r()$columns_source$cov_var)
       cov_is_numeric <- vapply(merged$anl_q()[[dataname]][input_cov_var], is.numeric, logical(1))
       interaction_var <- input_cov_var[cov_is_numeric]
@@ -998,10 +998,10 @@ srv_t_coxreg <- function(id,
     }
 
     ## generate table call with template and render table ----
-    all_q <- shiny::reactive({
+    all_q <- reactive({
       validate_checks()
 
-      ANL <- merged$anl_q()[["ANL"]] # nolint
+      ANL <- merged$anl_q()[["ANL"]]
       paramcd <- as.character(unique(ANL[[unlist(paramcd$filter)["vars_selected"]]]))
       multivariate <- input$type == "Multivariate"
       strata_var <- as.vector(merged$anl_input_r()$columns_source$strata_var)
@@ -1069,7 +1069,7 @@ srv_t_coxreg <- function(id,
       }
     })
 
-    table_r <- shiny::reactive(all_q()[["result"]])
+    table_r <- reactive(all_q()[["result"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
@@ -1078,14 +1078,14 @@ srv_t_coxreg <- function(id,
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(all_q())),
+      verbatim_content = reactive(teal.code::get_warnings(all_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(all_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
     )
 
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive(teal.code::get_code(all_q())),
+      verbatim_content = reactive(teal.code::get_code(all_q())),
       title = "R Code for the Current (Multi-Variable) Cox proportional hazard regression model"
     )
 
