@@ -170,7 +170,7 @@ template_events_by_grade <- function(dataname,
             indent_mod = -1L,
             split_fun = split_fun(grade),
             label_pos = "topleft",
-            split_label = formatters::var_labels(dataname[term_var])
+            split_label = teal.data::col_labels(dataname[term_var])
           ) %>%
           summarize_num_patients(
             var = id,
@@ -207,7 +207,7 @@ template_events_by_grade <- function(dataname,
             indent_mod = -1L,
             split_fun = split_fun(grade),
             label_pos = "topleft",
-            split_label = formatters::var_labels(dataname[hlt])
+            split_label = teal.data::col_labels(dataname[hlt])
           ) %>%
           summarize_occurrences_by_grade(
             var = grade,
@@ -221,7 +221,7 @@ template_events_by_grade <- function(dataname,
             indent_mod = -1L,
             split_fun = split_fun(grade),
             label_pos = "topleft",
-            split_label = formatters::var_labels(dataname[llt])
+            split_label = teal.data::col_labels(dataname[llt])
           ) %>%
           summarize_num_patients(
             var = id,
@@ -797,14 +797,13 @@ template_events_col_by_grade <- function(dataname,
 #' @examples
 #' data <- teal_data()
 #' data <- within(data, {
-#'   library(formatters)
 #'   library(dplyr)
 #'
 #'   ADSL <- tmc_ex_adsl
-#'   lbls_adae <- var_labels(tmc_ex_adae)
+#'   lbls_adae <- col_labels(tmc_ex_adae)
 #'   ADAE <- tmc_ex_adae %>%
 #'     mutate_if(is.character, as.factor) #' be certain of having factors
-#'   var_labels(ADAE) <- lbls_adae
+#'   col_labels(ADAE) <- lbls_adae
 #' })
 #'
 #' datanames <- c("ADSL", "ADAE")
@@ -864,7 +863,7 @@ tm_t_events_by_grade <- function(label,
                                  pre_output = NULL,
                                  post_output = NULL,
                                  basic_table_args = teal.widgets::basic_table_args()) {
-  logger::log_info("Initializing tm_t_events_by_grade")
+  message("Initializing tm_t_events_by_grade")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
@@ -914,17 +913,17 @@ tm_t_events_by_grade <- function(label,
 
 #' @keywords internal
 ui_t_events_by_grade <- function(id, ...) {
-  ns <- shiny::NS(id)
+  ns <- NS(id)
   a <- list(...)
   is_single_dataset_value <- teal.transform::is_single_dataset(a$arm_var, a$hlt, a$llt, a$grade)
 
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(a[c("arm_var", "hlt", "llt", "grade")]),
       teal.transform::data_extract_ui(
         id = ns("arm_var"),
@@ -950,12 +949,12 @@ ui_t_events_by_grade <- function(id, ...) {
         data_extract_spec = a$grade,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::checkboxInput(
+      checkboxInput(
         ns("add_total"),
         "Add All Patients column",
         value = a$add_total
       ),
-      shiny::checkboxInput(
+      checkboxInput(
         ns("col_by_grade"),
         "Display grade groupings in nested columns",
         value = a$col_by_grade
@@ -963,13 +962,13 @@ ui_t_events_by_grade <- function(id, ...) {
       teal.widgets::panel_group(
         teal.widgets::panel_item(
           "Additional table settings",
-          shiny::checkboxInput(
+          checkboxInput(
             ns("drop_arm_levels"),
             label = "Drop columns not in filtered analysis dataset",
             value = a$drop_arm_levels
           ),
-          shiny::helpText("Pruning Options"),
-          shiny::numericInput(
+          helpText("Pruning Options"),
+          numericInput(
             inputId = ns("prune_freq"),
             label = "Minimum Incidence Rate(%) in any of the treatment groups",
             value = a$prune_freq,
@@ -978,7 +977,7 @@ ui_t_events_by_grade <- function(id, ...) {
             step = 1,
             width = "100%"
           ),
-          shiny::numericInput(
+          numericInput(
             inputId = ns("prune_diff"),
             label = "Minimum Difference Rate(%) between any of the treatment groups",
             value = a$prune_diff,
@@ -990,7 +989,7 @@ ui_t_events_by_grade <- function(id, ...) {
         )
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
@@ -1022,7 +1021,7 @@ srv_t_events_by_grade <- function(id,
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
 
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     selector_list <- teal.transform::data_extract_multiple_srv(
       data_extract = list(arm_var = arm_var, hlt = hlt, llt = llt, grade = grade),
       datasets = data,
@@ -1043,11 +1042,11 @@ srv_t_events_by_grade <- function(id,
       )
     )
 
-    col_by_grade <- shiny::reactive({
+    col_by_grade <- reactive({
       input$col_by_grade
     })
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
       iv$add_rule(
         "prune_freq", shinyvalidate::sv_required("Please provide an Incidence Rate between 0 and 100 (%).")
@@ -1078,7 +1077,7 @@ srv_t_events_by_grade <- function(id,
       anl_name = "ANL_ADSL"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
@@ -1090,7 +1089,7 @@ srv_t_events_by_grade <- function(id,
       anl_q = anl_q
     )
 
-    validate_checks <- shiny::reactive({
+    validate_checks <- reactive({
       teal::validate_inputs(iv_r())
 
       adsl_filtered <- merged$anl_q()[[parentname]]
@@ -1109,20 +1108,23 @@ srv_t_events_by_grade <- function(id,
       )
       input_grade <- as.vector(merged$anl_input_r()$columns_source$grade)
 
-      shiny::validate(
-        shiny::need(is.factor(adsl_filtered[[input_arm_var]]), "Treatment variable is not a factor.")
+      validate(
+        need(is.factor(adsl_filtered[[input_arm_var]]), "Treatment variable is not a factor.")
       )
       if (input$col_by_grade) {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             is.factor(anl_filtered[[input_grade]]) &&
               all(as.character(unique(anl_filtered[[input_grade]])) %in% as.character(c(1:5))),
-            "Data includes records with grade levels outside of 1-5. Please use filter panel to exclude from analysis in order to display grade grouping in nested columns." # nolint
+            paste(
+              "Data includes records with grade levels outside of 1-5.",
+              "Please use filter panel to exclude from analysis in order to display grade grouping in nested columns."
+            )
           )
         )
       } else {
-        shiny::validate(
-          shiny::need(
+        validate(
+          need(
             is.factor(anl_filtered[[input_grade]]),
             "Event grade variable must be a factor."
           )
@@ -1140,9 +1142,9 @@ srv_t_events_by_grade <- function(id,
     })
 
     # The R-code corresponding to the analysis.
-    table_q <- shiny::reactive({
+    table_q <- reactive({
       validate_checks()
-      ANL <- merged$anl_q()[["ANL"]] # nolint
+      ANL <- merged$anl_q()[["ANL"]]
 
       input_hlt <- as.vector(merged$anl_input_r()$columns_source$hlt)
       input_llt <- as.vector(merged$anl_input_r()$columns_source$llt)
@@ -1198,7 +1200,7 @@ srv_t_events_by_grade <- function(id,
     })
 
     # Outputs to render.
-    table_r <- shiny::reactive({
+    table_r <- reactive({
       table_q()[["pruned_and_sorted_result"]]
     })
 
@@ -1209,15 +1211,15 @@ srv_t_events_by_grade <- function(id,
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(table_q())),
+      verbatim_content = reactive(teal.code::get_warnings(table_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(table_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(table_q())))
     )
 
     # Render R code.
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive(teal.code::get_code(table_q())),
+      verbatim_content = reactive(teal.code::get_code(table_q())),
       title = label
     )
 
