@@ -22,7 +22,7 @@ template_shift_by_arm <- function(dataname,
                                   aval_var = "ANRIND",
                                   base_var = lifecycle::deprecated(),
                                   baseline_var = "BNRIND",
-                                  na.rm = FALSE, # nolint
+                                  na.rm = FALSE, # nolint: object_name.
                                   na_level = default_na_str(),
                                   add_total = FALSE,
                                   total_label = default_total_label(),
@@ -110,7 +110,10 @@ template_shift_by_arm <- function(dataname,
           add_rowcounts() %>%
           analyze_vars(
             baseline_var,
-            denom = "N_row", na_level = na_str, na.rm = na.rm, .stats = "count_fraction"
+            denom = "N_row",
+            na_str = na_str,
+            na.rm = na.rm,
+            .stats = "count_fraction"
           ) %>%
           append_varlabels(dataname, baseline_var, indent = 1L),
         env = list(
@@ -142,7 +145,10 @@ template_shift_by_arm <- function(dataname,
           add_rowcounts() %>%
           analyze_vars(
             baseline_var,
-            denom = "N_row", na_level = na_str, na.rm = na.rm, .stats = "count_fraction"
+            denom = "N_row",
+            na_str = na_str,
+            na.rm = na.rm,
+            .stats = "count_fraction"
           ) %>%
           append_varlabels(dataname, baseline_var, indent = 1L),
         env = list(
@@ -249,7 +255,7 @@ tm_t_shift_by_arm <- function(label,
                                 selected = "ONTRTFL"
                               ),
                               treatment_flag = teal.transform::choices_selected("Y"),
-                              useNA = c("ifany", "no"), # nolint
+                              useNA = c("ifany", "no"), # nolint: object_name.
                               na_level = default_na_str(),
                               add_total = FALSE,
                               total_label = default_total_label(),
@@ -267,11 +273,11 @@ tm_t_shift_by_arm <- function(label,
     base_var <- baseline_var # resolves missing argument error
   }
 
-  logger::log_info("Initializing tm_t_shift_by_arm")
+  message("Initializing tm_t_shift_by_arm")
   checkmate::assert_string(label)
   checkmate::assert_string(dataname)
   checkmate::assert_string(parentname)
-  useNA <- match.arg(useNA) # nolint
+  useNA <- match.arg(useNA) # nolint: object_name.
   checkmate::assert_string(na_level)
   checkmate::assert_string(total_label)
   checkmate::assert_class(arm_var, "choices_selected")
@@ -319,7 +325,7 @@ tm_t_shift_by_arm <- function(label,
 
 #' @keywords internal
 ui_shift_by_arm <- function(id, ...) {
-  ns <- shiny::NS(id)
+  ns <- NS(id)
   a <- list(...)
 
   is_single_dataset_value <- teal.transform::is_single_dataset(
@@ -335,11 +341,11 @@ ui_shift_by_arm <- function(id, ...) {
 
   teal.widgets::standard_layout(
     output = teal.widgets::white_small_well(teal.widgets::table_with_settings_ui(ns("table"))),
-    encoding = shiny::div(
+    encoding = tags$div(
       ### Reporter
       teal.reporter::simple_reporter_ui(ns("simple_reporter")),
       ###
-      shiny::tags$label("Encodings", class = "text-primary"),
+      tags$label("Encodings", class = "text-primary"),
       teal.transform::datanames_input(a[c(
         "arm_var", "paramcd_var", "paramcd", "aval_var", "baseline_var", "visit_var", "treamtment_flag_var"
       )]),
@@ -373,8 +379,8 @@ ui_shift_by_arm <- function(id, ...) {
         data_extract_spec = a$baseline_var,
         is_single_dataset = is_single_dataset_value
       ),
-      shiny::checkboxInput(ns("add_total"), "Add All Patients row", value = a$add_total),
-      shiny::radioButtons(
+      checkboxInput(ns("add_total"), "Add All Patients row", value = a$add_total),
+      radioButtons(
         ns("useNA"),
         label = "Display NA counts",
         choices = c("ifany", "no"),
@@ -398,7 +404,7 @@ ui_shift_by_arm <- function(id, ...) {
         )
       )
     ),
-    forms = shiny::tagList(
+    forms = tagList(
       teal.widgets::verbatim_popup_ui(ns("warning"), button_label = "Show Warnings"),
       teal.widgets::verbatim_popup_ui(ns("rcode"), button_label = "Show R code")
     ),
@@ -430,7 +436,7 @@ srv_shift_by_arm <- function(id,
   with_filter <- !missing(filter_panel_api) && inherits(filter_panel_api, "FilterPanelAPI")
   checkmate::assert_class(data, "reactive")
   checkmate::assert_class(shiny::isolate(data()), "teal_data")
-  shiny::moduleServer(id, function(input, output, session) {
+  moduleServer(id, function(input, output, session) {
     selector_list <- teal.transform::data_extract_multiple_srv(
       data_extract = list(
         arm_var = arm_var,
@@ -453,7 +459,7 @@ srv_shift_by_arm <- function(id,
       )
     )
 
-    shiny::isolate({
+    isolate({
       resolved <- teal.transform::resolve_delayed(treatment_flag, as.list(data()@env))
       teal.widgets::updateOptionalSelectInput(
         session = session,
@@ -463,7 +469,7 @@ srv_shift_by_arm <- function(id,
       )
     })
 
-    iv_r <- shiny::reactive({
+    iv_r <- reactive({
       iv <- shinyvalidate::InputValidator$new()
       iv$add_rule(
         "treatment_flag",
@@ -484,7 +490,7 @@ srv_shift_by_arm <- function(id,
       anl_name = "ANL_ADSL"
     )
 
-    anl_q <- shiny::reactive({
+    anl_q <- reactive({
       data() %>%
         teal.code::eval_code(as.expression(anl_inputs()$expr)) %>%
         teal.code::eval_code(as.expression(adsl_inputs()$expr))
@@ -497,7 +503,7 @@ srv_shift_by_arm <- function(id,
     )
 
     # validate inputs
-    validate_checks <- shiny::reactive({
+    validate_checks <- reactive({
       teal::validate_inputs(iv_r())
 
       adsl_filtered <- merged$anl_q()[[parentname]]
@@ -508,8 +514,8 @@ srv_shift_by_arm <- function(id,
       input_baseline_var <- names(merged$anl_input_r()$columns_source$baseline_var)
       input_treatment_flag_var <- names(merged$anl_input_r()$columns_source$treatment_flag_var)
 
-      shiny::validate(
-        shiny::need(
+      validate(
+        need(
           nrow(merged$anl_q()[["ANL"]]) > 0,
           paste0(
             "Please make sure the analysis dataset is not empty or\n",
@@ -528,7 +534,7 @@ srv_shift_by_arm <- function(id,
     })
 
     # generate r code for the analysis
-    all_q <- shiny::reactive({
+    all_q <- reactive({
       validate_checks()
 
       my_calls <- template_shift_by_arm(
@@ -540,7 +546,7 @@ srv_shift_by_arm <- function(id,
         treatment_flag = input$treatment_flag,
         aval_var = names(merged$anl_input_r()$columns_source$aval_var),
         baseline_var = names(merged$anl_input_r()$columns_source$baseline_var),
-        na.rm = ifelse(input$useNA == "ifany", FALSE, TRUE), # nolint
+        na.rm = ifelse(input$useNA == "ifany", FALSE, TRUE),
         na_level = na_level,
         add_total = input$add_total,
         total_label = total_label,
@@ -551,7 +557,7 @@ srv_shift_by_arm <- function(id,
     })
 
     # Outputs to render.
-    table_r <- shiny::reactive(all_q()[["result"]])
+    table_r <- reactive(all_q()[["result"]])
 
     teal.widgets::table_with_settings_srv(
       id = "table",
@@ -561,15 +567,15 @@ srv_shift_by_arm <- function(id,
     # Render R code.
     teal.widgets::verbatim_popup_srv(
       id = "rcode",
-      verbatim_content = shiny::reactive(teal.code::get_code(all_q())),
+      verbatim_content = reactive(teal.code::get_code(all_q())),
       title = label
     )
 
     teal.widgets::verbatim_popup_srv(
       id = "warning",
-      verbatim_content = shiny::reactive(teal.code::get_warnings(all_q())),
+      verbatim_content = reactive(teal.code::get_warnings(all_q())),
       title = "Warning",
-      disabled = shiny::reactive(is.null(teal.code::get_warnings(all_q())))
+      disabled = reactive(is.null(teal.code::get_warnings(all_q())))
     )
 
     ### REPORTER
